@@ -3,6 +3,7 @@
 import pytest
 import os
 import logging
+from asgi_tools.tests import manage_lifespan
 
 from . import TestClient
 
@@ -34,27 +35,34 @@ def pytest_load_initial_conftests(early_config, parser, args):
 
 
 @pytest.fixture(scope='session')
-async def app(pytestconfig, request):
-    """Provide an example application."""
-    from muffin.utils import import_app
-
+async def app(pytestconfig, request, aiolib):
+    """Load an application, run lifespan events, prepare plugins."""
     if not pytestconfig.app:
         logging.warning(
             'Improperly configured. Please set ``muffin_app`` in your pytest config. '
             'Or use ``--muffin-app`` command option.')
         return
 
+    from muffin.utils import import_app
+
     app = import_app(pytestconfig.app)
+    msg = f"Setup application '{app.cfg.name}'"
+    if app.cfg.config:
+        msg += f"with config '{app.cfg.config}'"
+    app.logger.info(msg)
 
-    # Setup plugins
-    for plugin in app.plugins.values():
-        if hasattr(plugin, 'conftest'):
-            await plugin.conftest()
+    async with manage_lifespan(app):
 
-    return app
+        # Setup plugins
+        for plugin in app.plugins.values():
+            if hasattr(plugin, 'conftest') and plugin.conftest is not None:
+                app.logger.info(f"Setup plugin '{plugin.name}'")
+                await plugin.conftest()
+
+        yield app
 
 
 @pytest.fixture
-async def client(app):
+def client(app):
     """Generate a test client for the app."""
     return TestClient(app)
